monitorCointegration
This procedure is able to monitor a cointegration model for level or
trend cointegration and returns the corresponding break point, if
available. It is based on parameter estimation on a pre-break
"calibration" period at the beginning of the sample that is known or
assumed to be free of structural change. monitorStationarity
This procedure is a special case of monitorCointegration,
since it's able to monitor a one-dimensional vector for level or
trend stationarity. print
Print clear results.
plot
Plot the test statitics and the values/residuals of a
cointmonitoR model.
cointReg package.vignette("cointmonitoR")See the DESCRIPTION:
help(package = cointmonitoR)
See the README: https://github.com/aschersleben/cointmonitoR/blob/master/README.md
Open the package documentation page:
package?cointmonitoR
Further information and bug reporting: https://github.com/aschersleben/cointmonitoR